<?php

namespace Drupal\targets\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a config form for targets functionality.
 */
class TargetsSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['targets.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'targets_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('targets.settings');
    $form['redirect_status_code'] = [
      '#type' => 'select',
      '#title' => $this->t('Redirect status code'),
      '#default_value' => $config->get('redirect_status_code'),
      '#options' => [
        301 => $this->t('301 - moved permanently'),
        302 => $this->t('302 - moved temporarily'),
        307 => $this->t('307 - temporary redirect, not cached'),
      ],
      '#description' => $this->t('This redirect is used when user visits naked domain or a page with wrong target prefix.'),
    ];
    $form['excluded_paths'] = [
      '#type' => 'textarea',
      '#rows' => 10,
      '#title' => $this->t('Paths to exclude'),
      '#description' => $this->t('Enter one path per line, e.g. /node/1 or /path-to-exclude'),
      '#default_value' => implode(PHP_EOL, $config->get('excluded_paths')),
      '#size' => 60,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $excluded = preg_split("[\n|\r]", $form_state->getValue('excluded_paths'));
    $excluded = array_filter($excluded);

    $this->config('targets.settings')
      ->set('redirect_status_code', $form_state->getValue('redirect_status_code'))
      ->set('excluded_paths', $excluded)
      ->save();

    parent::submitForm($form, $form_state);
  }

}
